@@ -2,6 +2,7 @@ test_that("pmaxC works", {
   x <- 1:10
   expect_equal(pmaxC(x, 3L), pmax(x, 3L))
   expect_equal(pmaxC(x, 3), pmax(x, 3))
+  expect_equal(pmaxC(x, 3, dbl_ok = FALSE), pmax(x, 3))
 })
 
 test_that("pmaxC in-place", {
@@ -24,7 +25,7 @@ test_that("pmaxC error handling", {
   expect_error(pmaxC("", ""), regexp = "numeric")
   expect_error(pmaxC(list(1), 1L), regexp = "atomic")
   expect_error(pmaxC(1:5, 1:2), "length.*2")
-  expect_message(pmaxC(1:5, 0.5), "Output is double.")
+  expect_message(pmaxC(1:5, 1.5), "Output is double")
   expect_error(pmaxC(1:5, 2.5, dbl_ok = FALSE))
 })
 
@@ -41,11 +42,19 @@ test_that("pmaxC_int_real", {
   o <- pmax(x, 2)
   pmaxC(x, 2, in_place = TRUE)
   expect_equal(x, o)
+  x <- 1:5
+  ans <- pmaxC(x, 2.5, in_place = TRUE)
+  expect_equal(ans, pmax(1:5, 2.5))
+
   xd <- 1:5 + 0
   pmaxC(xd, 2L, in_place = TRUE)
   expect_equal(xd, o)
-
-
-
+  expect_equal(pmaxC(1:3, 3e9, in_place = TRUE), rep(3e9, 3))
 })
 
+test_that("pmaxC real int", {
+  x <- c(0, 1.5)
+  expect_equal(pmaxC(x, 1L), pmax(x, 1L))
+})
+
+
