@@ -6,7 +6,8 @@ test_that("pminC int", {
   expect_identical(pminC(y, 0L, in_place = TRUE), res)
   expect_equal(pminC(y, 0L), y)
   expect_equal(pminC(y, 0), y)
-
+  expect_equal(pminC(x, 3, dbl_ok = FALSE), pmin(x, 3))
+  expect_equal(pminC(integer(0), 1L), integer(0))
 
 })
 
@@ -23,6 +24,8 @@ test_that("pminC in-place", {
   expect_equal(pminC(oi, 2L), pmin(oi, 2L))
   pminC(oi, 2L, in_place = TRUE)
   expect_equal(oi, pmin2)
+
+  expect_equal(pminC(1:3, -3e9, in_place = TRUE), rep(-3e9, 3))
 })
 
 
@@ -30,6 +33,7 @@ test_that("pminC Error handling", {
   expect_error(pminC(1:5, 0L, in_place = "not logical"))
   expect_error(pminC("abc", "abc"), regexp = "numeric")
   expect_error(pminC(0:1, "abc"), regexp = "numeric")
+  expect_message(pminC(1:5, 1.5), "Output is double")
 })
 
 test_that("pminC_real_real", {
@@ -40,4 +44,10 @@ test_that("pminC_real_real", {
   expect_equal(pminC(x, y, keep_nas = TRUE), pmin(x, y))
 })
 
+test_that("pminC real_int", {
+  x <- runif(100)
+  expect_equal(pminC(x, 1L), pmin(x, 1))
+})
+
+
 
